@@ -10,10 +10,11 @@ use cid::multihash::Code;
 use cid::Cid;
 use fil_actors_runtime::runtime::Policy;
 use fil_actors_runtime::{actor_error, ActorDowncast, ActorError, Array};
-use fvm_shared::blockstore::{Blockstore, CborStore};
+use fvm_ipld_blockstore::Blockstore;
+use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
+use fvm_ipld_encoding::CborStore;
 use fvm_shared::clock::{ChainEpoch, QuantSpec};
 use fvm_shared::econ::TokenAmount;
-use fvm_shared::encoding::tuple::*;
 use fvm_shared::error::ExitCode;
 use fvm_shared::sector::{PoStProof, SectorSize};
 use num_traits::{Signed, Zero};
@@ -57,7 +58,7 @@ impl Deadlines {
     ) -> anyhow::Result<Deadline> {
         if deadline_idx >= policy.wpost_period_deadlines {
             return Err(anyhow!(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "invalid deadline {}",
                 deadline_idx
             )));
@@ -67,7 +68,7 @@ impl Deadlines {
             .get_cbor(&self.due[deadline_idx as usize])?
             .ok_or_else(|| {
                 anyhow!(actor_error!(
-                    ErrIllegalState,
+                    USR_ILLEGAL_STATE,
                     "failed to lookup deadline {}",
                     deadline_idx
                 ))
@@ -252,11 +253,11 @@ impl Deadline {
             .get(partition_idx)
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("failed to lookup partition {}", partition_idx),
                 )
             })?
-            .ok_or_else(|| actor_error!(ErrNotFound, "no partition {}", partition_idx))?;
+            .ok_or_else(|| actor_error!(USR_NOT_FOUND, "no partition {}", partition_idx))?;
 
         Ok(partition.clone())
     }
@@ -272,11 +273,13 @@ impl Deadline {
             .get(partition_idx)
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("failed to lookup partition snapshot {}", partition_idx),
                 )
             })?
-            .ok_or_else(|| actor_error!(ErrNotFound, "no partition snapshot {}", partition_idx))?;
+            .ok_or_else(|| {
+                actor_error!(USR_NOT_FOUND, "no partition snapshot {}", partition_idx)
+            })?;
 
         Ok(partition.clone())
     }
@@ -365,9 +368,11 @@ impl Deadline {
         self.partitions = partitions.flush()?;
 
         // Update early expiration bitmap.
-        for partition_idx in partitions_with_early_terminations {
-            self.early_terminations.set(partition_idx);
-        }
+        let new_early_terminations = BitField::try_from_bits(partitions_with_early_terminations)
+            .map_err(
+                |_| actor_error!(USR_ILLEGAL_STATE; "partition index out of bitfield range"),
+            )?;
+        self.early_terminations |= &new_early_terminations;
 
         let all_on_time_sectors = BitField::union(&on_time_sectors);
         let all_early_sectors = BitField::union(&early_sectors);
@@ -572,7 +577,7 @@ impl Deadline {
                     e.downcast_wrap(format!("failed to load partition {}", partition_idx))
                 })?
                 .ok_or_else(
-                    || actor_error!(ErrNotFound; "failed to find partition {}", partition_idx),
+                    || actor_error!(USR_NOT_FOUND; "failed to find partition {}", partition_idx),
                 )?
                 .clone();
 
@@ -647,8 +652,8 @@ impl Deadline {
         let partition_count = old_partitions.count();
         let to_remove_set: BTreeSet<_> = to_remove
             .bounded_iter(partition_count)
-            .map_err(
-                |e| actor_error!(ErrIllegalArgument; "failed to expand partitions into map: {}", e),
+            .ok_or_else(
+                || actor_error!(USR_ILLEGAL_ARGUMENT; "partitions to remove exceeds total"),
             )?
             .collect();
 
@@ -657,7 +662,7 @@ impl Deadline {
         if let Some(&max_partition) = to_remove_set.iter().max() {
             if max_partition > partition_count {
                 return Err(
-                    actor_error!(ErrIllegalArgument; "partition index {} out of range [0, {})", max_partition, partition_count).into()
+                    actor_error!(USR_ILLEGAL_ARGUMENT; "partition index {} out of range [0, {})", max_partition, partition_count).into()
                 );
             }
         } else {
@@ -668,7 +673,7 @@ impl Deadline {
         // Should already be checked earlier, but we might as well check again.
         if !self.early_terminations.is_empty() {
             return Err(
-                actor_error!(ErrIllegalArgument; "cannot remove partitions from deadline with early terminations").into(),
+                actor_error!(USR_ILLEGAL_ARGUMENT; "cannot remove partitions from deadline with early terminations").into(),
             );
         }
 
@@ -693,7 +698,7 @@ impl Deadline {
                 let has_no_faults = partition.faults.is_empty();
                 if !has_no_faults {
                     return Err(actor_error!(
-                        ErrIllegalArgument,
+                        USR_ILLEGAL_ARGUMENT,
                         "cannot remove partition {}: has faults",
                         partition_idx
                     )
@@ -704,7 +709,7 @@ impl Deadline {
                 let all_proven = partition.unproven.is_empty();
                 if !all_proven {
                     return Err(actor_error!(
-                        ErrIllegalArgument,
+                        USR_ILLEGAL_ARGUMENT,
                         "cannot remove partition {}: has unproven sectors",
                         partition_idx
                     )
@@ -773,11 +778,11 @@ impl Deadline {
                 .get(partition_idx)
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to load partition {}", partition_idx),
                     )
                 })?
-                .ok_or_else(|| actor_error!(ErrNotFound; "no such partition {}", partition_idx))?
+                .ok_or_else(|| actor_error!(USR_NOT_FOUND; "no such partition {}", partition_idx))?
                 .clone();
 
             let (new_faults, partition_power_delta, partition_new_faulty_power) = partition
@@ -804,14 +809,17 @@ impl Deadline {
 
             partitions.set(partition_idx, partition).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("failed to store partition {}", partition_idx),
                 )
             })?;
         }
 
         self.partitions = partitions.flush().map_err(|e| {
-            e.downcast_default(ExitCode::ErrIllegalState, "failed to store partitions root")
+            e.downcast_default(
+                ExitCode::USR_ILLEGAL_STATE,
+                "failed to store partitions root",
+            )
         })?;
 
         self.add_expiration_partitions(
@@ -822,7 +830,7 @@ impl Deadline {
         )
         .map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 "failed to update expirations for partitions with faults",
             )
         })?;
@@ -844,20 +852,20 @@ impl Deadline {
                 .get(partition_idx)
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to load partition {}", partition_idx),
                     )
                 })?
-                .ok_or_else(|| actor_error!(ErrNotFound; "no such partition {}", partition_idx))?
+                .ok_or_else(|| actor_error!(USR_NOT_FOUND; "no such partition {}", partition_idx))?
                 .clone();
 
             partition
                 .declare_faults_recovered(sectors, sector_size, sector_numbers)
-                .map_err(|e| e.downcast_wrap("failed to add recoveries"))?;
+                .map_err(|e| actor_error!(USR_ILLEGAL_STATE; "failed to add recoveries: {}", e))?;
 
             partitions.set(partition_idx, partition).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("failed to update partition {}", partition_idx),
                 )
             })?;
@@ -866,7 +874,10 @@ impl Deadline {
         // Power is not regained until the deadline end, when the recovery is confirmed.
 
         self.partitions = partitions.flush().map_err(|e| {
-            e.downcast_default(ExitCode::ErrIllegalState, "failed to store partitions root")
+            e.downcast_default(
+                ExitCode::USR_ILLEGAL_STATE,
+                "failed to store partitions root",
+            )
         })?;
 
         Ok(())
@@ -882,7 +893,7 @@ impl Deadline {
         fault_expiration_epoch: ChainEpoch,
     ) -> Result<(PowerPair, PowerPair), ActorError> {
         let mut partitions = self.partitions_amt(store).map_err(|e| {
-            e.downcast_default(ExitCode::ErrIllegalState, "failed to load partitions")
+            e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load partitions")
         })?;
 
         let mut detected_any = false;
@@ -900,11 +911,11 @@ impl Deadline {
                 .get(partition_idx)
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to load partition {}", partition_idx),
                     )
                 })?
-                .ok_or_else(|| actor_error!(ErrIllegalState; "no partition {}", partition_idx))?
+                .ok_or_else(|| actor_error!(USR_ILLEGAL_STATE; "no partition {}", partition_idx))?
                 .clone();
 
             // If we have no recovering power/sectors, and all power is faulty, skip
@@ -922,7 +933,7 @@ impl Deadline {
                 .record_missed_post(store, fault_expiration_epoch, quant)
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!(
                             "failed to record missed PoSt for partition {}",
                             partition_idx
@@ -940,7 +951,7 @@ impl Deadline {
             // Save new partition state.
             partitions.set(partition_idx, partition).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("failed to update partition {}", partition_idx),
                 )
             })?;
@@ -954,7 +965,7 @@ impl Deadline {
         // Save modified deadline state.
         if detected_any {
             self.partitions = partitions.flush().map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to store partitions")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to store partitions")
             })?;
         }
 
@@ -966,7 +977,7 @@ impl Deadline {
         )
         .map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 "failed to update deadline expiration queue",
             )
         })?;
@@ -982,7 +993,7 @@ impl Deadline {
         .flush()
         .map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 "failed to clear pending proofs array",
             )
         })?;
@@ -1120,15 +1131,15 @@ impl Deadline {
         fault_expiration: ChainEpoch,
         post_partitions: &mut [PoStPartition],
     ) -> anyhow::Result<PoStResult> {
-        let mut partition_indexes = BitField::new();
-        for p in post_partitions.iter() {
-            partition_indexes.set(p.index);
-        }
+        let partition_indexes = BitField::try_from_bits(post_partitions.iter().map(|p| p.index))
+            .map_err(
+                |_| actor_error!(USR_ILLEGAL_STATE; "partition index out of bitfield range"),
+            )?;
 
         let num_partitions = partition_indexes.len();
         if num_partitions != post_partitions.len() as u64 {
             return Err(anyhow!(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "duplicate partitions proven"
             )));
         }
@@ -1138,7 +1149,7 @@ impl Deadline {
         let already_proven = &self.partitions_posted & &partition_indexes;
         if !already_proven.is_empty() {
             return Err(anyhow!(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "parition already proven: {:?}",
                 already_proven
             )));
@@ -1159,7 +1170,7 @@ impl Deadline {
             let mut partition = partitions
                 .get(post.index)
                 .map_err(|e| e.downcast_wrap(format!("failed to load partition {}", post.index)))?
-                .ok_or_else(|| actor_error!(ErrNotFound; "no such partition {}", post.index))?
+                .ok_or_else(|| actor_error!(USR_NOT_FOUND; "no such partition {}", post.index))?
                 .clone();
 
             // Process new faults and accumulate new faulty power.
@@ -1208,7 +1219,7 @@ impl Deadline {
             // This will be rolled back if the method aborts with a failed proof.
             partitions.set(post.index, partition).map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     format!("failed to update partition {}", post.index),
                 )
             })?;
@@ -1226,7 +1237,7 @@ impl Deadline {
         self.add_expiration_partitions(store, fault_expiration, &rescheduled_partitions, quant)
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to update expirations for partitions with faults",
                 )
             })?;
@@ -1236,7 +1247,7 @@ impl Deadline {
         self.faulty_power += &new_faulty_power_total;
 
         self.partitions = partitions.flush().map_err(|e| {
-            e.downcast_default(ExitCode::ErrIllegalState, "failed to persist partitions")
+            e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to persist partitions")
         })?;
 
         // Collect all sectors, faults, and recoveries for proof verification.
@@ -1298,7 +1309,7 @@ impl Deadline {
         let post = proof_arr
             .delete(idx)
             .map_err(|e| e.downcast_wrap(format!("failed to retrieve proof {}", idx)))?
-            .ok_or_else(|| actor_error!(ErrIllegalArgument, "proof {} not found", idx))?;
+            .ok_or_else(|| actor_error!(USR_ILLEGAL_ARGUMENT, "proof {} not found", idx))?;
 
         let root = proof_arr
             .flush()
