@@ -4,16 +4,16 @@
 use std::convert::TryInto;
 use std::ops::{self, Neg};
 
-use anyhow::anyhow;
+use anyhow::{anyhow, Context};
 use bitfield::{BitField, UnvalidatedBitField, Validate};
 use cid::Cid;
 use fil_actors_runtime::runtime::Policy;
 use fil_actors_runtime::{actor_error, ActorDowncast, Array};
+use fvm_ipld_blockstore::Blockstore;
+use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
 use fvm_shared::bigint::bigint_ser;
-use fvm_shared::blockstore::Blockstore;
 use fvm_shared::clock::{ChainEpoch, QuantSpec, NO_QUANTIZATION};
 use fvm_shared::econ::TokenAmount;
-use fvm_shared::encoding::tuple::*;
 use fvm_shared::error::ExitCode;
 use fvm_shared::sector::{SectorSize, StoragePower};
 use num_traits::{Signed, Zero};
@@ -218,7 +218,7 @@ impl Partition {
         quant: QuantSpec,
     ) -> anyhow::Result<(BitField, PowerPair, PowerPair)> {
         validate_partition_contains_sectors(self, sector_numbers)
-            .map_err(|e| actor_error!(ErrIllegalArgument; "failed fault declaration: {}", e))?;
+            .map_err(|e| actor_error!(USR_ILLEGAL_ARGUMENT; "failed fault declaration: {}", e))?;
 
         let sector_numbers = sector_numbers
             .validate()
@@ -316,7 +316,7 @@ impl Partition {
     ) -> anyhow::Result<()> {
         // Check that the declared sectors are actually assigned to the partition.
         validate_partition_contains_sectors(self, sector_numbers)
-            .map_err(|e| actor_error!(ErrIllegalArgument; "failed fault declaration: {}", e))?;
+            .map_err(|e| actor_error!(USR_ILLEGAL_ARGUMENT; "failed fault declaration: {}", e))?;
 
         let sector_numbers = sector_numbers
             .validate()
@@ -378,7 +378,7 @@ impl Partition {
     ) -> anyhow::Result<Vec<SectorOnChainInfo>> {
         let sector_numbers = sector_numbers.validate().map_err(|e| {
             actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "failed to validate rescheduled sectors: {}",
                 e
             )
@@ -494,14 +494,16 @@ impl Partition {
         let live_sectors = self.live_sectors();
         let sector_numbers = sector_numbers.validate().map_err(|e| {
             actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "failed to validate terminating sectors: {}",
                 e
             )
         })?;
 
         if !live_sectors.contains_all(sector_numbers) {
-            return Err(actor_error!(ErrIllegalArgument, "can only terminate live sectors").into());
+            return Err(
+                actor_error!(USR_ILLEGAL_ARGUMENT, "can only terminate live sectors").into(),
+            );
         }
 
         let sector_infos = sectors.load_sector(sector_numbers)?;
@@ -682,7 +684,7 @@ impl Partition {
                 let to_process = if limit < count {
                     let to_process = sectors
                         .slice(0, limit)
-                        .map_err(|e| anyhow!("failed to slice early terminations: {}", e))?;
+                        .context("expected more sectors in bitfield")?;
                     let rest = sectors - &to_process;
                     remaining = Some((rest, epoch));
                     result.sectors_processed += limit;
@@ -747,7 +749,7 @@ impl Partition {
     ) -> anyhow::Result<(PowerPair, PowerPair, PowerPair, bool)> {
         let skipped = skipped.validate().map_err(|e| {
             actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "failed to validate skipped sectors: {}",
                 e
             )
@@ -765,7 +767,7 @@ impl Partition {
         // Check that the declared sectors are actually in the partition.
         if !self.sectors.contains_all(skipped) {
             return Err(actor_error!(
-                ErrIllegalArgument,
+                USR_ILLEGAL_ARGUMENT,
                 "skipped faults contains sectors outside partition"
             )
             .into());
@@ -795,7 +797,7 @@ impl Partition {
                 quant,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::ErrIllegalState, "failed to add skipped faults")
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to add skipped faults")
             })?;
 
         // Remove faulty recoveries
