@@ -8,7 +8,7 @@ use bitfield::BitField;
 use cid::Cid;
 use fil_actors_runtime::{actor_error, ActorDowncast, ActorError, Array};
 use fvm_ipld_amt::Error as AmtError;
-use fvm_shared::blockstore::Blockstore;
+use fvm_ipld_blockstore::Blockstore;
 use fvm_shared::error::ExitCode;
 use fvm_shared::sector::{SectorNumber, MAX_SECTOR_NUMBER};
 
@@ -33,7 +33,7 @@ impl<'db, BS: Blockstore> Sectors<'db, BS> {
             Ok(sector_numbers) => sector_numbers,
             Err(e) => {
                 return Err(actor_error!(
-                    ErrIllegalArgument,
+                    USR_ILLEGAL_ARGUMENT,
                     "failed to load sectors: {}",
                     e
                 ))
@@ -47,12 +47,14 @@ impl<'db, BS: Blockstore> Sectors<'db, BS> {
                 .get(sector_number)
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         format!("failed to load sector {}", sector_number),
                     )
                 })?
                 .cloned()
-                .ok_or_else(|| actor_error!(ErrNotFound; "sector not found: {}", sector_number))?;
+                .ok_or_else(
+                    || actor_error!(USR_NOT_FOUND; "sector not found: {}", sector_number),
+                )?;
             sector_infos.push(sector_on_chain);
         }
         Ok(sector_infos)
