@@ -14,14 +14,14 @@ use fil_actors_runtime::{
     ActorError, Array,
 };
 use fvm_ipld_amt::Error as AmtError;
+use fvm_ipld_blockstore::Blockstore;
+use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
+use fvm_ipld_encoding::{serde_bytes, BytesDe, Cbor, CborStore};
 use fvm_ipld_hamt::Error as HamtError;
 use fvm_shared::address::Address;
 use fvm_shared::bigint::bigint_ser;
-use fvm_shared::blockstore::{Blockstore, CborStore};
 use fvm_shared::clock::{ChainEpoch, QuantSpec, EPOCH_UNDEFINED};
 use fvm_shared::econ::TokenAmount;
-use fvm_shared::encoding::tuple::*;
-use fvm_shared::encoding::{serde_bytes, BytesDe, Cbor};
 use fvm_shared::error::ExitCode;
 use fvm_shared::sector::{RegisteredPoStProof, SectorNumber, SectorSize, MAX_SECTOR_NUMBER};
 use fvm_shared::HAMT_BIT_WIDTH;
@@ -133,7 +133,7 @@ impl State {
             .flush()
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to construct empty precommit map",
                 )
             })?;
@@ -142,7 +142,7 @@ impl State {
                 .flush()
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         "failed to construct empty precommits array",
                     )
                 })?;
@@ -151,7 +151,7 @@ impl State {
                 .flush()
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalState,
+                        ExitCode::USR_ILLEGAL_STATE,
                         "failed to construct sectors array",
                     )
                 })?;
@@ -159,14 +159,14 @@ impl State {
             .put_cbor(&BitField::new(), Code::Blake2b256)
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to construct empty bitfield",
                 )
             })?;
         let deadline = Deadline::new(store)?;
         let empty_deadline = store.put_cbor(&deadline, Code::Blake2b256).map_err(|e| {
             e.downcast_default(
-                ExitCode::ErrIllegalState,
+                ExitCode::USR_ILLEGAL_STATE,
                 "failed to construct illegal state",
             )
         })?;
@@ -175,7 +175,7 @@ impl State {
             .put_cbor(&Deadlines::new(policy, empty_deadline), Code::Blake2b256)
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to construct illegal state",
                 )
             })?;
@@ -184,7 +184,7 @@ impl State {
             .put_cbor(&VestingFunds::new(), Code::Blake2b256)
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to construct illegal state",
                 )
             })?;
@@ -215,7 +215,7 @@ impl State {
     pub fn get_info<BS: Blockstore>(&self, store: &BS) -> anyhow::Result<MinerInfo> {
         match store.get_cbor(&self.info) {
             Ok(Some(info)) => Ok(info),
-            Ok(None) => Err(actor_error!(ErrNotFound, "failed to get miner info").into()),
+            Ok(None) => Err(actor_error!(USR_NOT_FOUND, "failed to get miner info").into()),
             Err(e) => Err(e.downcast_wrap("failed to get miner info")),
         }
     }
@@ -276,11 +276,13 @@ impl State {
             .get_cbor(&self.allocated_sectors)
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::ErrIllegalState,
+                    ExitCode::USR_ILLEGAL_STATE,
                     "failed to load allocated sectors bitfield",
                 )
             })?
-            .ok_or_else(|| actor_error!(ErrIllegalState, "allocated sectors bitfield not found"))?;
+            .ok_or_else(|| {
+                actor_error!(USR_ILLEGAL_STATE, "allocated sectors bitfield not found")
+            })?;
 
         if policy != CollisionPolicy::AllowCollisions {
             // NOTE: A fancy merge algorithm could extract this intersection while merging, below, saving
@@ -288,7 +290,7 @@ impl State {
             let collisions = &prior_allocation & sector_numbers;
             if !collisions.is_empty() {
                 return Err(actor_error!(
-                    ErrIllegalArgument,
+                    USR_ILLEGAL_ARGUMENT,
                     "sector numbers {:?} already allocated",
                     collisions
                 ));
@@ -300,7 +302,7 @@ impl State {
                 .put_cbor(&new_allocation, Code::Blake2b256)
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::ErrIllegalArgument,
+                        ExitCode::USR_ILLEGAL_ARGUMENT,
                         format!(
                             "failed to store allocated sectors bitfield after adding {:?}",
                             sector_numbers,
@@ -667,7 +669,7 @@ impl State {
 
         if !partition.sectors.get(sector_number) {
             return Err(actor_error!(
-                ErrNotFound;
+                USR_NOT_FOUND;
                 "sector {} not a member of partition {}, deadline {}",
                 sector_number, partition_idx, deadline_idx
             )
@@ -676,7 +678,7 @@ impl State {
 
         if partition.faults.get(sector_number) {
             return Err(actor_error!(
-                ErrForbidden;
+                USR_FORBIDDEN;
                 "sector {} not a member of partition {}, deadline {}",
                 sector_number, partition_idx, deadline_idx
             )
@@ -685,7 +687,7 @@ impl State {
 
         if partition.terminated.get(sector_number) {
             return Err(actor_error!(
-                ErrNotFound;
+                USR_NOT_FOUND;
                 "sector {} not of partition {}, deadline {} is terminated",
                 sector_number, partition_idx, deadline_idx
             )
@@ -707,9 +709,11 @@ impl State {
     pub fn load_deadlines<BS: Blockstore>(&self, store: &BS) -> Result<Deadlines, ActorError> {
         store
             .get_cbor::<Deadlines>(&self.deadlines)
-            .map_err(|e| e.downcast_default(ExitCode::ErrIllegalState, "failed to load deadlines"))?
+            .map_err(|e| {
+                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load deadlines")
+            })?
             .ok_or_else(
-                || actor_error!(ErrIllegalState; "failed to load deadlines {}", self.deadlines),
+                || actor_error!(USR_ILLEGAL_STATE; "failed to load deadlines {}", self.deadlines),
             )
     }
 
@@ -731,7 +735,7 @@ impl State {
                     format!("failed to load vesting funds {}", self.vesting_funds),
                 )
             })?
-            .ok_or_else(|| actor_error!(ErrNotFound; "failed to load vesting funds {:?}", self.vesting_funds))?)
+            .ok_or_else(|| actor_error!(USR_NOT_FOUND; "failed to load vesting funds {:?}", self.vesting_funds))?)
     }
 
     /// Saves the vesting table to the store.
@@ -869,7 +873,7 @@ impl State {
         let unlocked_balance = self.get_unlocked_balance(curr_balance)?;
         if unlocked_balance < self.fee_debt {
             return Err(actor_error!(
-                ErrInsufficientFunds,
+                USR_INSUFFICIENT_FUNDS,
                 "unlocked balance can not repay fee debt ({} < {})",
                 unlocked_balance,
                 self.fee_debt
@@ -1169,13 +1173,13 @@ impl State {
         for sector_no in sector_nos.iter() {
             if sector_no as u64 > MAX_SECTOR_NUMBER {
                 return Err(
-                    actor_error!(ErrIllegalArgument; "sector number greater than maximum").into(),
+                    actor_error!(USR_ILLEGAL_ARGUMENT; "sector number greater than maximum").into(),
                 );
             }
             let info: &SectorPreCommitOnChainInfo =
                 precommitted
                     .get(&u64_key(sector_no as u64))?
-                    .ok_or_else(|| actor_error!(ErrNotFound, "sector {} not found", sector_no))?;
+                    .ok_or_else(|| actor_error!(USR_NOT_FOUND, "sector {} not found", sector_no))?;
             precommits.push(info.clone());
         }
         Ok(precommits)
@@ -1252,11 +1256,11 @@ impl MinerInfo {
     ) -> Result<Self, ActorError> {
         let sector_size = window_post_proof_type
             .sector_size()
-            .map_err(|e| actor_error!(ErrIllegalArgument, "invalid sector size: {}", e))?;
+            .map_err(|e| actor_error!(USR_ILLEGAL_ARGUMENT, "invalid sector size: {}", e))?;
 
         let window_post_partition_sectors = window_post_proof_type
             .window_post_partitions_sector()
-            .map_err(|e| actor_error!(ErrIllegalArgument, "invalid partition sectors: {}", e))?;
+            .map_err(|e| actor_error!(USR_ILLEGAL_ARGUMENT, "invalid partition sectors: {}", e))?;
 
         Ok(Self {
             owner,
