@@ -1,3 +1,5 @@
+use std::convert::TryInto;
+
 use fil_actors_runtime::test_utils::*;
 use fil_actors_runtime::INIT_ACTOR_ADDR;
 
@@ -6,10 +8,9 @@ use fil_actor_miner::{
     Actor, Deadline, Deadlines, Method, MinerConstructorParams as ConstructorParams, State,
 };
 
+use fvm_ipld_encoding::{BytesDe, CborStore, RawBytes};
 use fvm_shared::address::Address;
-use fvm_shared::blockstore::CborStore;
 use fvm_shared::econ::TokenAmount;
-use fvm_shared::encoding::{blake2b_256, BytesDe, RawBytes};
 use fvm_shared::error::ExitCode;
 use fvm_shared::sector::{RegisteredPoStProof, SectorSize};
 
@@ -29,6 +30,17 @@ struct TestEnv {
     rt: MockRuntime,
 }
 
+fn blake2b_256(data: &[u8]) -> [u8; 32] {
+    blake2b_simd::Params::new()
+        .hash_length(32)
+        .to_state()
+        .update(data)
+        .finalize()
+        .as_bytes()
+        .try_into()
+        .expect("fixed array size")
+}
+
 fn prepare_env() -> TestEnv {
     let mut env = TestEnv {
         receiver: Address::new_id(1000),
@@ -83,7 +95,7 @@ fn simple_construction() {
         RawBytes::default(),
         TokenAmount::from(0),
         RawBytes::serialize(env.worker_key).unwrap(),
-        ExitCode::Ok,
+        ExitCode::OK,
     );
 
     let result = env
@@ -171,7 +183,7 @@ fn control_addresses_are_resolved_during_construction() {
         RawBytes::default(),
         TokenAmount::from(0),
         RawBytes::serialize(env.worker_key).unwrap(),
-        ExitCode::Ok,
+        ExitCode::OK,
     );
 
     let result = env
@@ -210,7 +222,7 @@ fn fails_if_control_address_is_not_an_account_actor() {
         RawBytes::default(),
         TokenAmount::from(0),
         RawBytes::serialize(env.worker_key).unwrap(),
-        ExitCode::Ok,
+        ExitCode::OK,
     );
 
     let result = env
@@ -220,7 +232,7 @@ fn fails_if_control_address_is_not_an_account_actor() {
             &RawBytes::serialize(params).unwrap(),
         )
         .unwrap_err();
-    assert_eq!(result.exit_code(), ExitCode::ErrIllegalArgument);
+    assert_eq!(result.exit_code(), ExitCode::USR_ILLEGAL_ARGUMENT);
     env.rt.verify();
 }
 
@@ -239,7 +251,7 @@ fn test_construct_with_invalid_peer_id() {
             &RawBytes::serialize(params).unwrap(),
         )
         .unwrap_err();
-    assert_eq!(result.exit_code(), ExitCode::ErrIllegalArgument);
+    assert_eq!(result.exit_code(), ExitCode::USR_ILLEGAL_ARGUMENT);
     env.rt.verify();
 }
 
@@ -261,7 +273,7 @@ fn fails_if_control_addresses_exceeds_maximum_length() {
             &RawBytes::serialize(params).unwrap(),
         )
         .unwrap_err();
-    assert_eq!(result.exit_code(), ExitCode::ErrIllegalArgument);
+    assert_eq!(result.exit_code(), ExitCode::USR_ILLEGAL_ARGUMENT);
     env.rt.verify();
 }
 
@@ -284,7 +296,7 @@ fn test_construct_with_large_multiaddr() {
             &RawBytes::serialize(params).unwrap(),
         )
         .unwrap_err();
-    assert_eq!(result.exit_code(), ExitCode::ErrIllegalArgument);
+    assert_eq!(result.exit_code(), ExitCode::USR_ILLEGAL_ARGUMENT);
     env.rt.verify();
 }
 
@@ -305,6 +317,6 @@ fn test_construct_with_empty_multiaddr() {
             &RawBytes::serialize(params).unwrap(),
         )
         .unwrap_err();
-    assert_eq!(result.exit_code(), ExitCode::ErrIllegalArgument);
+    assert_eq!(result.exit_code(), ExitCode::USR_ILLEGAL_ARGUMENT);
     env.rt.verify();
 }
